from typing import List, Optional

def file_names_in_directory(path_name: str): ...
def file_paths_in_directory(path_name: str, filter_extensions: Optional[List[str]] = ...) -> List[str]: ...
def directory_names_in_directory(path_name: str): ...
def directory_paths_in_directory(path_name: str): ...
def get_latest_file_in_directory(path: str): ...
def paths_in_directory(directory: str) -> List[str]: ...
