from typing import List

def create_paths(paths: List[str]) -> None: ...
def copy_directory(source_directory: str, target_directory: str) -> None: ...
def clean_directory(directory: str, recursive: bool = ...): ...
