from nwon_baseline.typings import TerminalColors as TerminalColors, TerminalStyling as TerminalStyling

def print_with_color_and_style(text: str, color: TerminalColors, style: TerminalStyling) -> None: ...
def print_with_style(text: str, style: TerminalStyling) -> None: ...
