from nwon_baseline.typings import TerminalColors as TerminalColors

def print_red(text: str): ...
def print_green(text: str): ...
def print_blue(text: str): ...
def print_cyan(text: str): ...
def print_white(text: str): ...
def print_yellow(text: str): ...
def print_magenta(text: str): ...
def print_grey(text: str): ...
def print_black(text: str): ...
def print_default(text: str): ...
def print_warning(text: str): ...
def print_error(text: str): ...
def print_success(text: str): ...
def print_color(text: str, color: TerminalColors) -> None: ...
